@@ -935,7 +935,7 @@ class Sequence(Generic[T], Iterable[T]):
         return FlatteningSequence(self, transform)
     
 
-    def group_by(self, key_selector: Callable[[T], K]) -> Dict[K, Sequence[T]]:
+    def group_by(self, key_selector: Callable[[T], K]) -> GroupingSequence[K, T]:
         """
          Returns a dictionary with keys being the result of [key_selector] function being invoked on each element of original collection
         and values being the corresponding elements of original collection.
@@ -943,9 +943,9 @@ class Sequence(Generic[T], Iterable[T]):
          Example 1:
         >>> lst = [1, 2, 3, 4, 5]
         >>> it(lst).group_by(lambda x: x%2)
-        {1: [1, 3, 5], 0: [2, 4]}
+        [(1, [1, 3, 5]), (0, [2, 4])]
         """
-        return self.group_by_to(dict(), key_selector)
+        return GroupingSequence(self, key_selector)
     
 
     def group_by_to(self, destination: Dict[K, List[T]], key_selector: Callable[[T], K]) -> Dict[K, List[T]]:
@@ -1208,6 +1208,30 @@ class MergingSequence(Sequence[V]):
             except StopIteration:
                 break
 
+class GroupingSequence(Sequence[Tuple[K, List[T]]]):
+    def __init__(self, iterable: Iterable[T], key_func: Callable[[T], K]) -> None:
+        self._iter = iterable
+        self._key_func = key_func
+    
+    @property
+    def keys(self) -> Sequence[K]:
+        return self.map(lambda x: x[0])
+    
+    @property
+    def values(self) -> Sequence[List[T]]:
+        return self.map(lambda x: x[1])
+    
+    @property
+    def items(self) -> Sequence[Tuple[K, List[T]]]:
+        return self
+    
+    def __iter__(self) -> Iterator[Tuple[K, List[T]]]:
+        from collections import defaultdict
+        d = defaultdict(list)
+        for e in self._iter:
+            d[self._key_func(e)].append(e)
+        yield from d.items()
+
 
 def sequence(iterable: Iterable[T]) -> Sequence[T]:
     """
